@@ -385,6 +385,7 @@ pub struct Settings {
     pub network_timeout: u64,
     pub local_timeout: f64,
     pub enter_accept: bool,
+    pub smart_sort: bool,
 
     #[serde(default)]
     pub stats: Stats,
@@ -526,7 +527,13 @@ impl Settings {
         if !self.needs_update_check()? {
             // Worst case, we don't want Atuin to fail to start because something funky is going on with
             // version checking.
-            let version = match Settings::read_from_data_dir(LATEST_VERSION_FILENAME) {
+            let version = tokio::task::spawn_blocking(|| {
+                Settings::read_from_data_dir(LATEST_VERSION_FILENAME)
+            })
+            .await
+            .expect("file task panicked");
+
+            let version = match version {
                 Some(v) => Version::parse(&v).unwrap_or(current),
                 None => current,
             };
@@ -540,8 +547,14 @@ impl Settings {
         #[cfg(not(feature = "sync"))]
         let latest = current;
 
-        Settings::save_version_check_time()?;
-        Settings::save_to_data_dir(LATEST_VERSION_FILENAME, latest.to_string().as_str())?;
+        let latest_encoded = latest.to_string();
+        tokio::task::spawn_blocking(move || {
+            Settings::save_version_check_time()?;
+            Settings::save_to_data_dir(LATEST_VERSION_FILENAME, &latest_encoded)?;
+            Ok::<(), eyre::Report>(())
+        })
+        .await
+        .expect("file task panicked")?;
 
         Ok(latest)
     }
@@ -631,6 +644,7 @@ impl Settings {
             .set_default("keymap_mode", "emacs")?
             .set_default("keymap_mode_shell", "auto")?
             .set_default("keymap_cursor", HashMap::<String, String>::new())?
+            .set_default("smart_sort", false)?
             .set_default(
                 "prefers_reduced_motion",
                 std::env::var("NO_MOTION")
