@@ -31,8 +31,7 @@ bindkey -M vicmd 'k' atuin-up-search-vicmd";
 pub async fn init(store: AliasStore, disable_up_arrow: bool, disable_ctrl_r: bool) -> Result<()> {
     init_static(disable_up_arrow, disable_ctrl_r);
 
-    let aliases = store.aliases().await?;
-    let aliases = atuin_dotfiles::shell::zsh::build(&aliases[..]);
+    let aliases = atuin_dotfiles::shell::zsh::config(&store).await;
 
     println!("{aliases}");
 
