@@ -29,6 +29,7 @@ use super::{
     cursor::Cursor,
     engines::{SearchEngine, SearchState},
     history_list::{HistoryList, ListState, PREFIX_LENGTH},
+    sort,
 };
 
 use crate::{command::client::search::engines, VERSION};
@@ -65,6 +66,7 @@ pub struct State {
     results_len: usize,
     accept: bool,
     keymap_mode: KeymapMode,
+    prefix: bool,
     current_cursor: Option<CursorStyle>,
     tab_index: usize,
 
@@ -81,13 +83,21 @@ struct StyleState {
 }
 
 impl State {
-    async fn query_results(&mut self, db: &mut dyn Database) -> Result<Vec<History>> {
+    async fn query_results(
+        &mut self,
+        db: &mut dyn Database,
+        smart_sort: bool,
+    ) -> Result<Vec<History>> {
         let results = self.engine.query(&self.search, db).await?;
 
         self.results_state.select(0);
         self.results_len = results.len();
 
-        Ok(results)
+        if smart_sort {
+            Ok(sort::sort(self.search.input.as_str(), results))
+        } else {
+            Ok(results)
+        }
     }
 
     fn handle_input<W>(
@@ -191,35 +201,45 @@ impl State {
         let ctrl = input.modifiers.contains(KeyModifiers::CONTROL);
         let esc_allow_exit = !(self.tab_index == 0 && self.keymap_mode == KeymapMode::VimInsert);
 
+        // support ctrl-a prefix, like screen or tmux
+        if ctrl && input.code == KeyCode::Char('a') {
+            self.prefix = true;
+            return InputAction::Continue;
+        }
+
         // core input handling, common for all tabs
-        match input.code {
-            KeyCode::Char('c' | 'g') if ctrl => return InputAction::ReturnOriginal,
-            KeyCode::Esc if esc_allow_exit => {
-                return Self::handle_key_exit(settings);
-            }
-            KeyCode::Char('[') if ctrl && esc_allow_exit => {
-                return Self::handle_key_exit(settings);
-            }
-            KeyCode::Tab => {
-                return InputAction::Accept(self.results_state.selected());
-            }
+        let common: Option<InputAction> = match input.code {
+            KeyCode::Char('c' | 'g') if ctrl => Some(InputAction::ReturnOriginal),
+            KeyCode::Esc if esc_allow_exit => Some(Self::handle_key_exit(settings)),
+            KeyCode::Char('[') if ctrl && esc_allow_exit => Some(Self::handle_key_exit(settings)),
+            KeyCode::Tab => Some(InputAction::Accept(self.results_state.selected())),
             KeyCode::Char('o') if ctrl => {
                 self.tab_index = (self.tab_index + 1) % TAB_TITLES.len();
 
-                return InputAction::Continue;
+                Some(InputAction::Continue)
             }
 
-            _ => {}
+            _ => None,
+        };
+
+        if let Some(ret) = common {
+            self.prefix = false;
+
+            return ret;
         }
 
         // handle tab-specific input
-        match self.tab_index {
+        let action = match self.tab_index {
             0 => self.handle_search_input(settings, input),
 
             1 => super::inspector::input(self, settings, self.results_state.selected(), input),
 
             _ => panic!("invalid tab index on input"),
-        }
+        };
+
+        self.prefix = false;
+
+        action
     }
 
     fn handle_search_scroll_one_line(
@@ -266,7 +286,24 @@ impl State {
         // reset the state, will be set to true later if user really did change it
         self.switched_search_mode = false;
 
-        // First handle keymap specific keybindings.
+        // first up handle prefix mappings. these take precedence over all others
+        // eg, if a user types ctrl-a d, delete the history
+        if self.prefix {
+            // It'll be expanded.
+            #[allow(clippy::single_match)]
+            match input.code {
+                KeyCode::Char('d') => {
+                    return InputAction::Delete(self.results_state.selected());
+                }
+                KeyCode::Char('a') => {
+                    self.search.input.start();
+                    return InputAction::Continue;
+                }
+                _ => {}
+            }
+        }
+
+        // handle keymap specific keybindings.
         match self.keymap_mode {
             KeymapMode::VimNormal => match input.code {
                 KeyCode::Char('/') if !ctrl => {
@@ -368,7 +405,6 @@ impl State {
                 .next_word(&settings.word_chars, settings.word_jump_mode),
             KeyCode::Right => self.search.input.right(),
             KeyCode::Char('f') if ctrl => self.search.input.right(),
-            KeyCode::Char('a') if ctrl => self.search.input.start(),
             KeyCode::Home => self.search.input.start(),
             KeyCode::Char('e') if ctrl => self.search.input.end(),
             KeyCode::End => self.search.input.end(),
@@ -379,6 +415,21 @@ impl State {
             KeyCode::Backspace => {
                 self.search.input.back();
             }
+            KeyCode::Char('h' | '?') if ctrl => {
+                // Depending on the terminal, [Backspace] can be transmitted as
+                // \x08 or \x7F.  Also, [Ctrl+Backspace] can be transmitted as
+                // \x08 or \x7F or \x1F.  On the other hand, [Ctrl+h] and
+                // [Ctrl+?] are also transmitted as \x08 or \x7F by the
+                // terminals.
+                //
+                // The crossterm library translates \x08 and \x7F to C-h and
+                // Backspace, respectively.  With the extended keyboard
+                // protocol enabled, crossterm can faithfully translate
+                // [Ctrl+h] and [Ctrl+?] to C-h and C-?.  There is no perfect
+                // solution, but we treat C-h and C-? the same as backspace to
+                // suppress quirks as much as possible.
+                self.search.input.back();
+            }
             KeyCode::Delete if ctrl => self
                 .search
                 .input
@@ -960,11 +1011,12 @@ pub async fn history(
         } else {
             Box::new(OffsetDateTime::now_utc)
         },
+        prefix: false,
     };
 
     app.initialize_keymap_cursor(settings);
 
-    let mut results = app.query_results(&mut db).await?;
+    let mut results = app.query_results(&mut db, settings.smart_sort).await?;
 
     let mut stats: Option<HistoryStats> = None;
     let accept;
@@ -1025,7 +1077,7 @@ pub async fn history(
             || initial_filter_mode != app.search.filter_mode
             || initial_search_mode != app.search_mode
         {
-            results = app.query_results(&mut db).await?;
+            results = app.query_results(&mut db, settings.smart_sort).await?;
         }
 
         stats = if app.tab_index == 0 {
